Module convert

Module convert 

Conversion between core types and plugin serialization types.

Enums

ConversionError
Error returned when converting a wrapper back to a directive fails.

Functions

directive_to_wrapper
Convert a directive to its serializable wrapper.
directives_to_wrappers
Convert a list of directives to serializable wrappers.
wrapper_to_directive
Convert a serializable wrapper back to a directive.
wrappers_to_directives
Convert a list of serializable wrappers back to directives.