directive_to_wrapper_with_location

Function directive_to_wrapper_with_location 

pub fn directive_to_wrapper_with_location(
    directive: &Directive,
    filename: Option<String>,
    lineno: Option<u32>,
) -> DirectiveWrapper
Convert a directive to its serializable wrapper with source location.

The filename and lineno parameters are used for error reporting when the directive is later processed by plugins.