pub struct CheckClosingPlugin;Expand description
Plugin that inserts zero balance assertion when posting has closing: TRUE metadata.
When a posting has metadata closing: TRUE, this plugin adds a balance assertion
for that account with zero balance on the next day.