pub struct CheckDrainedPlugin;Expand description
Plugin that inserts zero balance assertions when balance sheet accounts are closed.
When a Close directive is encountered for an account (Assets, Liabilities, or Equity), this plugin generates Balance directives with zero amounts for all currencies that were used in that account. The assertions are dated one day after the close date.