pub struct CoherentCostPlugin;Expand description
Plugin that ensures currencies use cost OR price consistently, never both.
If a currency is used with cost notation {...}, it should not also be used
with price notation @ in the same ledger, as this can lead to inconsistencies.