pub struct NoUnusedPlugin;Expand description
Plugin that identifies accounts that are opened but never used.
Reports a warning for each account that has an Open directive but is never referenced in any transaction, balance, pad, or other directive.