pub struct UnrealizedPlugin {
pub gains_account: String,
}Expand description
Plugin that calculates unrealized gains on positions.
For each position held at cost, this plugin can generate unrealized gain/loss entries based on current market prices from the price database.
Fields
gains_account: StringAccount to book unrealized gains to.
Implementations
Sourceimpl UnrealizedPlugin
impl UnrealizedPlugin
Sourcepub const fn with_account(account: String) -> Self
pub const fn with_account(account: String) -> Self
Create with a custom gains account.