validate_plugin_module

Function validate_plugin_module 

pub fn validate_plugin_module(bytes: &[u8]) -> Result<()>
Validate that a WASM module doesn’t have any forbidden imports.

Beancount plugins should be self-contained and not require any external imports (WASI, env, etc.). This function checks that the module only has the expected exports and no unexpected imports.

Errors

Returns an error if the module has forbidden imports or is missing required exports.