Conversion between core types and plugin serialization types.
Enums
- Conversion
Error - Error returned when converting a wrapper back to a directive fails.
Functions
- directive_
to_ wrapper - Convert a directive to its serializable wrapper.
- directives_
to_ wrappers - Convert a list of directives to serializable wrappers.
- wrapper_
to_ directive - Convert a serializable wrapper back to a directive.
- wrappers_
to_ directives - Convert a list of serializable wrappers back to directives.