Native (non-WASM) plugin support.
These plugins run as native Rust code for maximum performance. They implement the same interface as WASM plugins.
Modules
- utils
- Shared utility functions for native plugins.
Structs
- Auto
Accounts Plugin - Plugin that auto-generates Open directives for accounts used without explicit open.
- Auto
TagPlugin - Plugin that automatically adds tags based on account patterns.
- BoxAccrual
Plugin - Plugin for splitting capital losses across multiple years.
- Capital
Gains Gain Loss Plugin - Plugin for classifying capital gains into gains/losses categories.
- Capital
Gains Long Short Plugin - Plugin for classifying capital gains into long/short term categories.
- Check
Average Cost Plugin - Plugin that validates reducing postings use average cost for accounts with NONE booking.
- Check
Closing Plugin - Plugin that inserts zero balance assertion when posting has
closing: TRUEmetadata. - Check
Commodity Plugin - Plugin that checks all used commodities are declared.
- Check
Drained Plugin - Plugin that inserts zero balance assertions when balance sheet accounts are closed.
- Close
Tree Plugin - Plugin that closes all descendant accounts when a parent account closes.
- Coherent
Cost Plugin - Plugin that ensures currencies use cost OR price consistently, never both.
- Commodity
Attr Plugin - Plugin that validates Commodity directives have required metadata attributes.
- Currency
Accounts Plugin - Plugin that auto-generates currency trading account postings.
- Document
Discovery Plugin - Plugin that auto-discovers document files from configured directories.
- Effective
Date Plugin - Plugin for handling effective dates on postings.
- Forecast
Plugin - Plugin for generating recurring forecast transactions.
- Generate
Base CcyPrices Plugin - Plugin for generating base currency prices.
- Implicit
Prices Plugin - Plugin that generates price entries from transaction costs and prices.
- Leaf
Only Plugin - Plugin that errors when posting to non-leaf (parent) accounts.
- Native
Plugin Registry - Registry of built-in native plugins.
- NoDuplicates
Plugin - Plugin that detects duplicate transactions based on hash.
- NoUnused
Plugin - Plugin that identifies accounts that are opened but never used.
- OneCommodity
Plugin - Plugin that enforces single commodity per account.
- Pedantic
Plugin - Meta-plugin that enables all strict validation plugins.
- Rename
Accounts Plugin - Plugin for renaming accounts using regex patterns.
- RxTxn
Plugin - Plugin for Regular Expected Transactions.
- Sell
Gains Plugin - Plugin that cross-checks declared gains against sale prices.
- Split
Expenses Plugin - Plugin for splitting expenses between multiple people.
- Unique
Prices Plugin - Plugin that enforces unique prices (one per commodity pair per day).
- Unrealized
Plugin - Plugin that calculates unrealized gains on positions.
- Valuation
Plugin - Plugin for tracking opaque fund values.
- Zerosum
Plugin - Plugin for matching zero-sum postings.
Traits
- Native
Plugin - Trait for native plugins.