pub struct CheckAverageCostPlugin { /* private fields */ }Expand description
Plugin that validates reducing postings use average cost for accounts with NONE booking.
For accounts with booking method NONE (average cost), when selling/reducing positions, this plugin verifies that the cost basis used matches the calculated average cost within a specified tolerance.
Implementations
Sourceimpl CheckAverageCostPlugin
impl CheckAverageCostPlugin
Sourcepub const fn with_tolerance(tolerance: Decimal) -> Self
pub const fn with_tolerance(tolerance: Decimal) -> Self
Create with custom tolerance.