pub struct ImplicitPricesPlugin;Expand description
Plugin that generates price entries from transaction costs and prices.
When a transaction has a posting with a cost or price annotation, this plugin generates a corresponding Price directive.